==> lookml-gen-0.1.0.tar.gz: lookml-gen-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0'
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='lookml-gen',
    version='0.1.0',
    description="Programmatically generate LookML",
    long_description=readme + '\n\n' + history,
    author="Joe Schmid",
    author_email='jschmid@symphonyrm.com',
    url='https://github.com/symphonyrm/lookml-gen',
    packages=[
        'lookml-gen',
    ],
    package_dir={'lookml-gen':
                 'lookml_gen'},
    entry_points={
        'console_scripts': [
            'lookml_gen=lookml_gen.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='lookml-gen',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)

==> lookml-gen-0.1.1.tar.gz: lookml-gen-0.1.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0'
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='lookml-gen',
    version='0.1.1',
    description="Programmatically generate LookML",
    long_description=readme + '\n\n' + history,
    author="Joe Schmid",
    author_email='jschmid@symphonyrm.com',
    url='https://github.com/symphonyrm/lookml-gen',
    packages=[
        'lookmlgen',
    ],
    package_dir={'lookmlgen':
                 'lookmlgen'},
    entry_points={
        'console_scripts': [
            'lookmlgen=lookmlgen.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='lookml-gen',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
